@@ -24,6 +24,7 @@ from os.path import basename, dirname, exists, join, isdir
 
 program = basename( sys.argv[0] )
 hostname = socket.gethostname().split('.')[0]
+os.umask(022)
 
 # Initialize twisted
 try:
@@ -39,8 +40,9 @@ BIN_DIR = dirname( os.path.abspath(__file__) )
 ROOT_DIR = dirname(BIN_DIR)
 STORAGE_DIR = join(ROOT_DIR, 'storage')
 LOG_DIR = join(STORAGE_DIR, 'log', 'carbon-cache')
-CONF_DIR = join(ROOT_DIR, 'conf')
 LIB_DIR = join(ROOT_DIR, 'lib')
+CONF_DIR = join(ROOT_DIR, 'conf')
+__builtins__.CONF_DIR = CONF_DIR # evil I know, but effective.
 
 sys.path.insert(0, LIB_DIR)
 
@@ -120,6 +122,15 @@ elif action == 'status':
     print "%s is not running" % program
     raise SystemExit(0)
 
+elif action != 'start':
+  parser.print_usage()
+  raise SystemExit(1)
+
+
+if exists(options.pidfile):
+  print "Pidfile %s already exists, is %s already running?" % (options.pidfile, program)
+  raise SystemExit(1)
+
 
 # Read config (we want failures to occur before daemonizing)
 settings.readFrom(options.config, 'cache')
@@ -145,9 +156,11 @@ else:
   if not isdir(options.logdir):
     os.makedirs(options.logdir)
 
+  if settings.USER:
+    print "Dropping privileges to become the user %s" % settings.USER
+
   from carbon.util import daemonize, dropprivs
   daemonize()
-  logToDir(options.logdir)
 
   pidfile = open(options.pidfile, 'w')
   pidfile.write( str(os.getpid()) )
@@ -162,9 +175,9 @@ else:
   if settings.USER:
     pwent = pwd.getpwnam(settings.USER)
     os.chown(options.pidfile, pwent.pw_uid, pwent.pw_gid)
-    print "Dropping privileges to become the user %s" % settings.USER
     dropprivs(settings.USER)
 
+  logToDir(options.logdir)
 
 # Configure application components
 metricReceived.installHandler(MetricCache.store)
