@@ -57,6 +57,13 @@ def optimalWriteOrder():
         createCount = 1
 
       elif createCount >= settings.MAX_CREATES_PER_MINUTE:
+        # dropping queued up datapoints for new metrics prevents filling up the entire cache
+        # when a bunch of new metrics are received.
+        try:
+          MetricCache.pop(metric)
+        except KeyError:
+          pass
+
         continue
 
     try: # metrics can momentarily disappear from the MetricCache due to the implementation of MetricCache.store()
@@ -92,10 +99,11 @@ def writeCachedDataPoints():
           raise Exception("No storage schema matched the metric '%s', check your storage-schemas.conf file.")
 
         dbDir = dirname(dbFilePath)
-        os.system("mkdir -p '%s'" % dbDir)
+        os.system("mkdir -p -m 755 '%s'" % dbDir)
 
         log.creates("creating database file %s" % dbFilePath)
         whisper.create(dbFilePath, archiveConfig)
+        os.chmod(dbFilePath, 0755)
         increment('creates')
 
         # Create metadata file
@@ -113,10 +121,12 @@ def writeCachedDataPoints():
         increment('errors')
       else:
         pointCount = len(datapoints)
-        log.updates("wrote %d datapoints for %s in %.5f seconds" % (pointCount, metric, updateTime))
         increment('committedPoints', pointCount)
         append('updateTimes', updateTime)
 
+        if settings.LOG_UPDATES:
+          log.updates("wrote %d datapoints for %s in %.5f seconds" % (pointCount, metric, updateTime))
+
         # Rate limit update operations
         thisSecond = int(t2)
 
@@ -134,6 +144,8 @@ def writeCachedDataPoints():
 
 
 def createMetaFile(metric, schema, path):
+  return #XXX disabled for now.
+
   metadata = {
     'interval' : min( [a.secondsPerPoint for a in schema.archives] ),
   }
